@@ -1,4 +1,4 @@
-from django.conf.urls import include, url
+from django.urls import include, re_path
 from django.contrib import admin
 from django.conf import settings
 from django.views.generic import TemplateView
@@ -28,10 +28,10 @@ def cause500(request):
 
 
 urlpatterns = [
-    url(r'^$', cove.input.views.data_input, name='index'),
-    url(r'^terms/$', TemplateView.as_view(template_name='terms.html'), name='terms'),
-    url(r'^stats/$', cove.views.stats, name='stats'),
-    url(r'^test/500$', cause500),
-    url(r'^admin/', admin.site.urls),
-    url(r'^i18n/', include('django.conf.urls.i18n'))
+    re_path(r'^$', cove.input.views.data_input, name='index'),
+    re_path(r'^terms/$', TemplateView.as_view(template_name='terms.html'), name='terms'),
+    re_path(r'^stats/$', cove.views.stats, name='stats'),
+    re_path(r'^test/500$', cause500),
+    re_path(r'^admin/', admin.site.urls),
+    re_path(r'^i18n/', include('django.conf.urls.i18n'))
 ]
